tox installation
==================================

Install info in a nutshell
----------------------------------

**Pythons**: CPython 2.6-3.6, Jython-2.5.1, pypy-1.9ff

**Operating systems**: Linux, Windows, OSX, Unix

**Installer Requirements**: setuptools_

**License**: MIT license

**git repository**: https://github.com/tox-dev/tox

Installation with pip
--------------------------------------

Use the following command:

.. code-block:: shell

   pip install tox

It is fine to install ``tox`` itself into a virtualenv_ environment.

Install from Checkout
-------------------------

Consult the GitHub page to get a checkout of the git repository:

    https://github.com/tox-dev/tox

and then install in your environment with something like:

.. code-block:: shell

    python setup.py install

or just activate your checkout in your environment like this:

.. code-block:: shell

    python setup.py develop

so that you can do changes and submit patches.

.. include:: links.rst
